==> bgp-bmp-api-0.13.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/bmp/message/rev200120/stat/tlvs/PerAfiSafiLocRibTlvBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.stat.tlvs;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.yang.types.rev130715.Gauge64;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.types.rev200120.AddressFamily;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.types.rev200120.SubsequentAddressFamily;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link PerAfiSafiLocRibTlvBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     PerAfiSafiLocRibTlvBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new PerAfiSafiLocRibTlvBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of PerAfiSafiLocRibTlvBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see PerAfiSafiLocRibTlvBuilder
 * @see Builder
 *
 */
public class PerAfiSafiLocRibTlvBuilder implements Builder<PerAfiSafiLocRibTlv> {

    private Class<? extends AddressFamily> _afi;
    private Gauge64 _count;
    private Class<? extends SubsequentAddressFamily> _safi;


    Map<Class<? extends Augmentation<PerAfiSafiLocRibTlv>>, Augmentation<PerAfiSafiLocRibTlv>> augmentation = Collections.emptyMap();

    public PerAfiSafiLocRibTlvBuilder() {
    }
    public PerAfiSafiLocRibTlvBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.AfiSafiGaugeTlv arg) {
        this._count = arg.getCount();
        this._afi = arg.getAfi();
        this._safi = arg.getSafi();
    }
    public PerAfiSafiLocRibTlvBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.Tlv arg) {
    }
    public PerAfiSafiLocRibTlvBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.multiprotocol.rev180329.BgpTableType arg) {
        this._afi = arg.getAfi();
        this._safi = arg.getSafi();
    }

    public PerAfiSafiLocRibTlvBuilder(PerAfiSafiLocRibTlv base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<PerAfiSafiLocRibTlv>>, Augmentation<PerAfiSafiLocRibTlv>> aug =((AugmentationHolder<PerAfiSafiLocRibTlv>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._afi = base.getAfi();
        this._count = base.getCount();
        this._safi = base.getSafi();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.AfiSafiGaugeTlv</li>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.multiprotocol.rev180329.BgpTableType</li>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.Tlv</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.AfiSafiGaugeTlv) {
            this._count = ((org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.AfiSafiGaugeTlv)arg).getCount();
            isValidArg = true;
        }
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.multiprotocol.rev180329.BgpTableType) {
            this._afi = ((org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.multiprotocol.rev180329.BgpTableType)arg).getAfi();
            this._safi = ((org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.multiprotocol.rev180329.BgpTableType)arg).getSafi();
            isValidArg = true;
        }
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.Tlv) {
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.AfiSafiGaugeTlv, org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.multiprotocol.rev180329.BgpTableType, org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.Tlv]");
    }

    public Class<? extends AddressFamily> getAfi() {
        return _afi;
    }
    
    public Gauge64 getCount() {
        return _count;
    }
    
    public Class<? extends SubsequentAddressFamily> getSafi() {
        return _safi;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<PerAfiSafiLocRibTlv>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public PerAfiSafiLocRibTlvBuilder setAfi(final Class<? extends AddressFamily> value) {
        this._afi = value;
        return this;
    }
    
    public PerAfiSafiLocRibTlvBuilder setCount(final Gauge64 value) {
        this._count = value;
        return this;
    }
    
    public PerAfiSafiLocRibTlvBuilder setSafi(final Class<? extends SubsequentAddressFamily> value) {
        this._safi = value;
        return this;
    }
    
    public PerAfiSafiLocRibTlvBuilder addAugmentation(Class<? extends Augmentation<PerAfiSafiLocRibTlv>> augmentationType, Augmentation<PerAfiSafiLocRibTlv> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public PerAfiSafiLocRibTlvBuilder removeAugmentation(Class<? extends Augmentation<PerAfiSafiLocRibTlv>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public PerAfiSafiLocRibTlv build() {
        return new PerAfiSafiLocRibTlvImpl(this);
    }

    private static final class PerAfiSafiLocRibTlvImpl
        extends AbstractAugmentable<PerAfiSafiLocRibTlv>
        implements PerAfiSafiLocRibTlv {
    
        private final Class<? extends AddressFamily> _afi;
        private final Gauge64 _count;
        private final Class<? extends SubsequentAddressFamily> _safi;
    
        PerAfiSafiLocRibTlvImpl(PerAfiSafiLocRibTlvBuilder base) {
            super(base.augmentation);
            this._afi = base.getAfi();
            this._count = base.getCount();
            this._safi = base.getSafi();
        }
    
        @Override
        public Class<? extends AddressFamily> getAfi() {
            return _afi;
        }
        
        @Override
        public Gauge64 getCount() {
            return _count;
        }
        
        @Override
        public Class<? extends SubsequentAddressFamily> getSafi() {
            return _safi;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_afi);
            result = prime * result + Objects.hashCode(_count);
            result = prime * result + Objects.hashCode(_safi);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!PerAfiSafiLocRibTlv.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            PerAfiSafiLocRibTlv other = (PerAfiSafiLocRibTlv)obj;
            if (!Objects.equals(_afi, other.getAfi())) {
                return false;
            }
            if (!Objects.equals(_count, other.getCount())) {
                return false;
            }
            if (!Objects.equals(_safi, other.getSafi())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                PerAfiSafiLocRibTlvImpl otherImpl = (PerAfiSafiLocRibTlvImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<PerAfiSafiLocRibTlv>>, Augmentation<PerAfiSafiLocRibTlv>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("PerAfiSafiLocRibTlv");
            CodeHelpers.appendValue(helper, "_afi", _afi);
            CodeHelpers.appendValue(helper, "_count", _count);
            CodeHelpers.appendValue(helper, "_safi", _safi);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> bgp-bmp-api-0.16.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/bmp/message/rev200120/stat/tlvs/PerAfiSafiLocRibTlvBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.stat.tlvs;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.yang.types.rev130715.Gauge64;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.multiprotocol.rev180329.BgpTableType;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.types.rev200120.AddressFamily;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.types.rev200120.SubsequentAddressFamily;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.AfiSafiGaugeTlv;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.Tlv;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link PerAfiSafiLocRibTlvBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     PerAfiSafiLocRibTlvBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new PerAfiSafiLocRibTlvBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of PerAfiSafiLocRibTlvBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see PerAfiSafiLocRibTlvBuilder
 * @see Builder
 *
 */
@Generated("mdsal-binding-generator")
public class PerAfiSafiLocRibTlvBuilder implements Builder<PerAfiSafiLocRibTlv> {

    private Class<? extends AddressFamily> _afi;
    private Gauge64 _count;
    private Class<? extends SubsequentAddressFamily> _safi;


    Map<Class<? extends Augmentation<PerAfiSafiLocRibTlv>>, Augmentation<PerAfiSafiLocRibTlv>> augmentation = Collections.emptyMap();

    public PerAfiSafiLocRibTlvBuilder() {
    }
    
    
    
    public PerAfiSafiLocRibTlvBuilder(AfiSafiGaugeTlv arg) {
        this._count = arg.getCount();
        this._afi = arg.getAfi();
        this._safi = arg.getSafi();
    }
    public PerAfiSafiLocRibTlvBuilder(Tlv arg) {
    }
    public PerAfiSafiLocRibTlvBuilder(BgpTableType arg) {
        this._afi = arg.getAfi();
        this._safi = arg.getSafi();
    }

    public PerAfiSafiLocRibTlvBuilder(PerAfiSafiLocRibTlv base) {
        Map<Class<? extends Augmentation<PerAfiSafiLocRibTlv>>, Augmentation<PerAfiSafiLocRibTlv>> aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this._afi = base.getAfi();
        this._count = base.getCount();
        this._safi = base.getSafi();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>AfiSafiGaugeTlv</li>
     * <li>BgpTableType</li>
     * <li>Tlv</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types or has property with incompatible value
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof AfiSafiGaugeTlv) {
            this._count = ((AfiSafiGaugeTlv)arg).getCount();
            isValidArg = true;
        }
        if (arg instanceof BgpTableType) {
            this._afi = ((BgpTableType)arg).getAfi();
            this._safi = ((BgpTableType)arg).getSafi();
            isValidArg = true;
        }
        if (arg instanceof Tlv) {
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[AfiSafiGaugeTlv, BgpTableType, Tlv]");
    }

    public Class<? extends AddressFamily> getAfi() {
        return _afi;
    }
    
    public Gauge64 getCount() {
        return _count;
    }
    
    public Class<? extends SubsequentAddressFamily> getSafi() {
        return _safi;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<PerAfiSafiLocRibTlv>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    
    public PerAfiSafiLocRibTlvBuilder setAfi(final Class<? extends AddressFamily> value) {
        this._afi = value;
        return this;
    }
    
    public PerAfiSafiLocRibTlvBuilder setCount(final Gauge64 value) {
        this._count = value;
        return this;
    }
    
    public PerAfiSafiLocRibTlvBuilder setSafi(final Class<? extends SubsequentAddressFamily> value) {
        this._safi = value;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public PerAfiSafiLocRibTlvBuilder addAugmentation(Augmentation<PerAfiSafiLocRibTlv> augmentation) {
        Class<? extends Augmentation<PerAfiSafiLocRibTlv>> augmentationType = augmentation.implementedInterface();
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public PerAfiSafiLocRibTlvBuilder removeAugmentation(Class<? extends Augmentation<PerAfiSafiLocRibTlv>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public PerAfiSafiLocRibTlv build() {
        return new PerAfiSafiLocRibTlvImpl(this);
    }

    private static final class PerAfiSafiLocRibTlvImpl
        extends AbstractAugmentable<PerAfiSafiLocRibTlv>
        implements PerAfiSafiLocRibTlv {
    
        private final Class<? extends AddressFamily> _afi;
        private final Gauge64 _count;
        private final Class<? extends SubsequentAddressFamily> _safi;
    
        PerAfiSafiLocRibTlvImpl(PerAfiSafiLocRibTlvBuilder base) {
            super(base.augmentation);
            this._afi = base.getAfi();
            this._count = base.getCount();
            this._safi = base.getSafi();
        }
    
        @Override
        public Class<? extends AddressFamily> getAfi() {
            return _afi;
        }
        
        @Override
        public Gauge64 getCount() {
            return _count;
        }
        
        @Override
        public Class<? extends SubsequentAddressFamily> getSafi() {
            return _safi;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = PerAfiSafiLocRibTlv.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return PerAfiSafiLocRibTlv.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return PerAfiSafiLocRibTlv.bindingToString(this);
        }
    }
}
